#include <bits/stdc++.h>

#define int long long

using namespace std;

mt19937 rnd(1337);

const int MOD = 1'000'000'007;

int n;

struct node;
typedef node * pnode;

struct node {
    pnode l = nullptr;
    pnode r = nullptr;
    int x;
    int y = rnd();
    int idx;
    int mx;

    node(int _idx, int _val) {
        mx = idx = _idx;
        x = n * _val + _idx;
    }
};

int get_max(pnode t) {
    if (t == nullptr) {
        return -1;
    }
    return t->mx;
}

void pull(pnode t) {
    t->mx = max(t->idx, max(get_max(t->l), get_max(t->r)));
}

pnode merge(pnode t1, pnode t2) {
    if (t1 == nullptr) return t2;
    if (t2 == nullptr) return t1;
    if (t1->y > t2->y) {
        t1->r = merge(t1->r, t2);
        pull(t1);
        return t1;
    } else {
        t2->l = merge(t1, t2->l);
        pull(t2);
        return t2;
    }
}

// <key, >=key
pair<pnode, pnode> split(pnode t, int key) {
    if (t == nullptr) return {nullptr, nullptr};
    if (t->x < key) {
        auto [t1, t2] = split(t->r, key);
        t->r = t1;
        pull(t);
        return {t, t2};
    } else {
        auto [t1, t2] = split(t->l, key);
        t->l = t2;
        pull(t);
        return {t1, t};
    }
}

pnode insert(pnode t, int idx, int val) {
    auto new_node = new node(idx, val);
    auto [t1, t2] = split(t, n * val + idx);
    return merge(merge(t1, new_node), t2);
}

pnode erase(pnode t, int idx, int val) {
    auto [t1, t23] = split(t, n * val + idx);
    auto [t2, t3] = split(t23, n * val + idx + 1);
    delete t2;
    return merge(t1, t3);
}

int query(pnode t, int ql, int qr) {
    auto [t1, t23] = split(t, n * ql);
    auto [t2, t3] = split(t23, n * (qr + 1));
    int res = get_max(t2);
    t23 = merge(t2, t3);
    t = merge(t1, t23);
    return res;
}

vector<vector<int>> gr;

vector<bool> used;
vector<int> topsort;

void dfs(int v) {
    used[v] = true;
    for (auto to : gr[v]) {
        if (used[to]) continue;
        dfs(to);
    }
    topsort.push_back(v);
}

void solve() {
    cin >> n;
    vector<int> l(n), r(n);
    for (int i = 0; i < n; ++i) {
        cin >> l[i] >> r[i];
    }
    vector<int> order(n);
    iota(order.begin(), order.end(), 0);
    sort(order.begin(), order.end(), [&] (int i, int j) {
        if (l[i] != l[j]) return l[i] < l[j];
        return r[i] > r[j];
    });

    pnode root = nullptr;
    for (int i = 0; i < n; ++i) {
        root = insert(root, i, r[order[i]]);
    }

    vector<vector<int>> qs(n);
    for (int i = 0; i < n; ++i) {
        qs[i].emplace_back(i);
    }

    gr.resize(n);

    for (int i = n - 1; i >= 0; --i) {
        root = erase(root, i, r[order[i]]);
        while (!qs[i].empty()) {
            int idx = qs[i].back();
            qs[i].pop_back();
            int j;
            if (idx == i) {
                j = query(root, r[order[idx]], 1'000'000'001);
            } else {
                j = query(root, r[order[idx]], r[order[i]] - 1);
            }
            if (j != -1) {
                gr[order[j]].push_back(order[idx]);
                qs[j].push_back(idx);
            }
        }
    }

    used.assign(n, false);

    for (int i = 0; i < n; ++i) {
        if (!used[i]) {
            dfs(i);
        }
    }

    vector<int> dp(n);

    for (auto i : topsort) {
        dp[i] = 1;
        for (auto to : gr[i]) {
            dp[i] += dp[to];
        }
        dp[i] %= MOD;
    }

    for (int i = 0; i < n; ++i) {
        cout << dp[i] << ' ';
    }
    cout << '\n';
}

int32_t main() {
#ifdef DDD
    freopen("../input.txt", "r", stdin);
#else
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
#endif

    solve();
}